=== modified file 'src/View/Sidebar.vala'
--- src/View/Sidebar.vala	2016-11-17 19:19:38 +0000
+++ src/View/Sidebar.vala	2016-11-28 18:23:42 +0000
@@ -1279,7 +1279,7 @@
                 } else if (flags == Marlin.OpenFlag.NEW_TAB) {
                     window.add_tab (location, Marlin.ViewMode.CURRENT);
                 } else {
-                    window.file_path_change_request (location);
+                    window.uri_path_change_request (uri);
                 }
             } else if (f != null) {
                 f (this);
@@ -1319,7 +1319,7 @@
                         } else if (flags == Marlin.OpenFlag.NEW_TAB) {
                             window.add_tab (location, Marlin.ViewMode.CURRENT);
                         } else {
-                            window.file_path_change_request (location);
+                            window.uri_path_change_request (location.get_uri ());
                         }
                     }
                 }

=== modified file 'src/View/Window.vala'
--- src/View/Window.vala	2016-11-28 17:51:12 +0000
+++ src/View/Window.vala	2016-11-28 18:23:42 +0000
@@ -316,11 +316,11 @@
             });
 
             tabs.tab_restored.connect ((label, restore_data, icon) => {
-                add_tab (File.new_for_uri (restore_data));
+                add_tab_by_uri (restore_data);
             });
 
             tabs.tab_duplicated.connect ((tab) => {
-                add_tab (File.new_for_uri (((tab.page as ViewContainer).uri)));
+                add_tab_by_uri (((ViewContainer)(tab.page)).uri);
             });
 
             tabs.tab_moved.connect ((tab, x, y) => {
@@ -448,6 +448,15 @@
             top_menu.working = current_tab.is_frozen;
         }
 
+        public void add_tab_by_uri (string uri, Marlin.ViewMode mode = Marlin.ViewMode.PREFERRED) {
+            var file = get_file_from_uri (uri);
+            if (file != null) {
+                add_tab (file, mode);
+            } else {
+                add_tab ();
+            }
+        }
+
         public void add_tab (File location = File.new_for_commandline_arg (Environment.get_home_dir ()),
                              Marlin.ViewMode mode = Marlin.ViewMode.PREFERRED) {
             mode = real_mode (mode);
@@ -1060,7 +1069,7 @@
             }
         }
 
-        public void file_path_change_request (GLib.File loc, Marlin.OpenFlag flag = Marlin.OpenFlag.DEFAULT) {
+        private void file_path_change_request (GLib.File loc, Marlin.OpenFlag flag = Marlin.OpenFlag.DEFAULT) {
             /* ViewContainer deals with non-existent or unmounted directories
              * and locations that are not directories */
             if (restoring_tabs) {
@@ -1079,13 +1088,23 @@
         }
 
         public void uri_path_change_request (string p, Marlin.OpenFlag flag = Marlin.OpenFlag.DEFAULT) {
+            var file = get_file_from_uri (p);
+            if (file != null) {
+                /* Have to escape path and use File.new_for_uri () to correctly handle paths with certain characters such as "#" */
+                file_path_change_request (file, flag);
+            } else {
+                warning ("Cannot browse %s", p);
+            }
+        }
+
+        /** Use this function to standardise how locations are generated from uris **/
+        private File? get_file_from_uri (string uri) {
             /* Sanitize path removes file:// scheme if present, but GOF.Directory.Async will replace it */
-            string path = PF.FileUtils.sanitize_path (p, current_tab.location.get_path ());
+            string path = PF.FileUtils.sanitize_path (uri, current_tab.location.get_path ());
             if (path.length > 0) {
-                /* Have to escape path and use File.new_for_uri () to correctly handle paths with certain characters such as "#" */
-                file_path_change_request (File.new_for_uri (PF.FileUtils.escape_uri (path)), flag);
+                return File.new_for_uri (PF.FileUtils.escape_uri (path));
             } else {
-                warning ("Cannot browse %s", p);
+                return null;
             }
         }
 

